CCL: /home/chisarie/Documents/lsst_ccl/CCL/include/ccl_massfunc.h Source File

CCL

ccl_massfunc.h
Go to the documentation of this file.
1
3 #pragma once
4
5 #include "ccl_core.h"
13 void ccl_cosmology_compute_sigma(ccl_cosmology * cosmo, int * status);
14
20 void ccl_cosmology_compute_hmfparams(ccl_cosmology * cosmo, int * status);
21
22 //TODO smooth_mass is not really correct in this function, tho it makes sense in compute_sigma
33 double ccl_massfunc(ccl_cosmology * cosmo, double smooth_mass, double a, double odelta, int * status);
34
35 //TODO status flag unused here
45 double ccl_halo_bias(ccl_cosmology *cosmo, double smooth_mass, double a, double odelta, int * status);
56 double ccl_massfunc_m2r(ccl_cosmology * cosmo, double smooth_mass, int * status);
57
68 double ccl_sigmaM(ccl_cosmology * cosmo, double smooth_mass, double a, int * status);
ccl_massfunc
double ccl_massfunc(ccl_cosmology *cosmo, double smooth_mass, double a, double odelta, int *status)
Definition: ccl_massfunc.c:408
ccl_core.h
ccl_sigmaM
double ccl_sigmaM(ccl_cosmology *cosmo, double smooth_mass, double a, int *status)
Definition: ccl_massfunc.c:465
ccl_cosmology_compute_sigma
void ccl_cosmology_compute_sigma(ccl_cosmology *cosmo, int *status)
Definition: ccl_massfunc.c:330
ccl_massfunc_m2r
double ccl_massfunc_m2r(ccl_cosmology *cosmo, double smooth_mass, int *status)
Definition: ccl_massfunc.c:447
ccl_halo_bias
double ccl_halo_bias(ccl_cosmology *cosmo, double smooth_mass, double a, double odelta, int *status)
Definition: ccl_massfunc.c:430
ccl_cosmology_compute_hmfparams
void ccl_cosmology_compute_hmfparams(ccl_cosmology *cosmo, int *status)
Definition: ccl_massfunc.c:16
ccl_cosmology
Definition: ccl_core.h:115